==> igniteui-react-charts-16.6.4.tgz: package/ES5/UltimateOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { UltimateOscillatorIndicatorCalculationStrategy } from "./UltimateOscillatorIndicatorCalculationStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var UltimateOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(UltimateOscillatorIndicator, _super);
    function UltimateOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UltimateOscillatorIndicator.prototype.get_p3 = function () {
        return new UltimateOscillatorIndicatorCalculationStrategy();
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "p3", {
        get: function () {
            return this.get_p3();
        },
        enumerable: true,
        configurable: true
    });
    UltimateOscillatorIndicator.prototype.get_qg = function () {
        return UltimateOscillatorIndicator.$;
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    UltimateOscillatorIndicator.$t = markType(UltimateOscillatorIndicator, 'UltimateOscillatorIndicator', StrategyBasedIndicator.$);
    return UltimateOscillatorIndicator;
}(StrategyBasedIndicator));
export { UltimateOscillatorIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/UltimateOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { UltimateOscillatorIndicatorCalculationStrategy } from "./UltimateOscillatorIndicatorCalculationStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var UltimateOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(UltimateOscillatorIndicator, _super);
    function UltimateOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UltimateOscillatorIndicator.prototype.get_p5 = function () {
        return new UltimateOscillatorIndicatorCalculationStrategy();
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    UltimateOscillatorIndicator.prototype.get_qi = function () {
        return UltimateOscillatorIndicator.$;
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    UltimateOscillatorIndicator.$t = markType(UltimateOscillatorIndicator, 'UltimateOscillatorIndicator', StrategyBasedIndicator.$);
    return UltimateOscillatorIndicator;
}(StrategyBasedIndicator));
export { UltimateOscillatorIndicator };
